<?php

/* Custom Post Layouts
==================================== */

function wpzoom_post_layout_options() {
	global $post;
	$postLayouts = array('side-right' => 'Sidebar on the right', 'side-left' => 'Sidebar on the left', 'full' => 'Full Width');
	?>

	<style>
	.RadioClass { display: none; }
	.RadioLabelClass { margin-right: 10px; }
	img.layout-select { border: solid 4px #c0cdd6; border-radius: 5px; }
	.RadioSelected img.layout-select { border: solid 4px #3173b2; }
 	</style>

	<script type="text/javascript">  
	jQuery(document).ready( function($) {
		$(".RadioClass").change(function(){  
		    if($(this).is(":checked")){  
		        $(".RadioSelected:not(:checked)").removeClass("RadioSelected");  
		        $(this).next("label").addClass("RadioSelected");  
		    }  
		}); 
	});  
	</script>

	<fieldset>
		<div>
 			<p>
 			<?php
			foreach ($postLayouts as $key => $value)
			{
				?>
				<input id="<?php echo $key; ?>" type="radio" class="RadioClass" name="wpzoom_post_template" value="<?php echo $key; ?>"<?php if (get_post_meta($post->ID, 'wpzoom_post_template', true) == $key) { echo' checked="checked"'; } ?> />
				<label for="<?php echo $key; ?>" class="RadioLabelClass<?php if (get_post_meta($post->ID, 'wpzoom_post_template', true) == $key) { echo' RadioSelected"'; } ?>">
				<img src="<?php echo wpzoom::$wpzoomPath; ?>/assets/images/layout-<?php echo $key; ?>.png" alt="<?php echo $value; ?>" title="<?php echo $value; ?>" class="layout-select" /></label>
			<?php
			} 
			?>
 			</p>
   		</div>
	</fieldset>
	<?php
}
 
 
/* Custom Posts Options	
==================================== */

add_action('admin_menu', 'wpzoom_options_box');

function wpzoom_options_box() {
 	add_meta_box('wpzoom_estate_default', 'Property Details', 'wpzoom_estate_details', 'estate', 'normal', 'high');
 	add_meta_box('wpzoom_estate_meta', 'Additional Details', 'wpzoom_estate_options', 'estate', 'normal', 'high');
   	add_meta_box('wpzoom_post_layout', 'Post Layout', 'wpzoom_post_layout_options', 'post', 'normal', 'high');
}
 

/* Property Additional Labels
==================================== */

function wpzoom_estate_options() {
	global $post;
	
	$options = array();
	
 	foreach (option::$options as $option => $val) {
	    if (strpos($option, 'listing') !== false && trim($val) != '') {
	        $options[] = $val;
	    }
	}
	
	foreach ($options as $option) {
	    $id = strtolower(str_replace(" ", "_", preg_replace("/[^a-zA-Z0-9\s]/", "", $option)));
	?>
	<fieldset>
		<table class="widefat estate_details">
			<tbody>
				<tr class="wpp_attribute_row">
					<th><label for="wpzoom_estate_<?php echo $id; ?>"><?php echo $option; ?></label></th>
					
					<td class="wpp_attribute_cell">
						<input type="text" name="wpzoom_estate_<?php echo $id; ?>" id="wpzoom_estate_<?php echo $id; ?>" value="<?php echo get_post_meta($post->ID, 'wpzoom_estate_' . $id, true); ?>"/>
					</td>
				</tr>
			</tbody>
		</table>
 	</fieldset>
	<?php
    }
    ?>
	
	<p class="description">You can add more property details in <a href="admin.php?page=wpzoom_options" target="_blank">Site Options &rarr; Additional Property Details</a></p>
	
	<?php 
}


/* Property Default Labels
==================================== */

function wpzoom_estate_details() {
	global $post;

	?>
	
	<fieldset>
 	<table class="widefat estate_details">
        <tbody>
  			<tr class="wpp_attribute_row">
				<th><label><?php _e('Property Status', 'wpzoom'); ?></label></th>
				
				<td class="wpp_attribute_cell">
 					<?php
						$box = array(
							'args' => array(
								'taxonomy' => 'status'
							),
							'title' => 'Status'
						);
						post_categories_meta_box($post, $box)
						?>                   
  				</td>
			</tr>
			
 			<tr class="wpp_attribute_row">
				<th><label><?php _e('Property Type', 'wpzoom'); ?></label></th>
				
				<td class="wpp_attribute_cell">
 					<?php
						$box = array(
							'args' => array(
								'taxonomy' => 'types'
							),
							'title' => 'Type'
						);
						post_categories_meta_box($post, $box)
						?>                   
  				</td>
			</tr>
  			
			<tr class="wpp_attribute_row">
				<th><label><?php _e('Location', 'wpzoom'); ?></label></th>
				
				<td class="wpp_attribute_cell">
 					<?php
						$box = array(
							'args' => array(
								'taxonomy' => 'location'
							),
							'title' => 'Locations'
						);
						post_categories_meta_box($post, $box)
						?>                   
  				</td>
			</tr>
  			
			<tr class="wpp_attribute_row">
				<th><label for="wpzoom_estate_wpzaddress"><?php _e('Address', 'wpzoom'); ?></label></th>
				
				<td class="wpp_attribute_cell">
					<input type="text" name="wpzoom_estate_wpzaddress" id="wpzoom_estate_wpzaddress" value="<?php echo get_post_meta($post->ID, 'wpzoom_estate_wpzaddress', true); ?>"/>		
 				</td>
			</tr>
			
    			<tr class="wpp_attribute_row">
				<th><label for="wpzoom_estate_wpzprice"><?php _e('Price in', 'wpzoom'); ?> <?php echo option::get('currency'); ?></label></th>
				
				<td class="wpp_attribute_cell">
					<input type="text" name="wpzoom_estate_wpzprice" id="wpzoom_estate_wpzprice" value="<?php echo get_post_meta($post->ID, 'wpzoom_estate_wpzprice', true); ?>"/>      
					<br/><span class="description" style="float:left;color:#9D9A9A; font-size:11px;">Enter the price of the property excluding the currency symbol. Type in only digits, no commas. Example: 100000 will appear as 100,000.</span>          
 				</td>
			</tr>
			
			<tr class="wpp_attribute_row">
				<th><label for="wpzoom_estate_wpzbedroom"><?php _e('Bedrooms', 'wpzoom'); ?></label></th>
				
				<td class="wpp_attribute_cell">
					<select name="wpzoom_estate_wpzbedroom" id="wpzoom_estate_wpzbedroom">
						<?php
						$i = 0; 
						while ($i < 9) {
						$i++;
						?>
						<option<?php selected( get_post_meta($post->ID, 'wpzoom_estate_wpzbedroom', true), $i ); ?>><?php echo $i; ?></option>
						<?php
						}
						?>
						<option<?php selected( get_post_meta($post->ID, 'wpzoom_estate_wpzbedroom', true), '10+' ); ?>>10+</option>
					</select>
 				</td>
			</tr>
			
			<tr class="wpp_attribute_row">
				<th><label for="wpzoom_estate_wpzbathroom"><?php _e('Bathrooms', 'wpzoom'); ?></label></th>
				
				<td class="wpp_attribute_cell">
					<select name="wpzoom_estate_wpzbathroom" id="wpzoom_estate_wpzbathroom">
						<?php
						$i = 0; 
						while ($i < 9) {
						$i++;
						?>
						<option<?php selected( get_post_meta($post->ID, 'wpzoom_estate_wpzbathroom', true), $i ); ?>><?php echo $i; ?></option>
						<?php
						}
						?>
						<option<?php selected( get_post_meta($post->ID, 'wpzoom_estate_wpzbathroom', true), '10+' ); ?>>10+</option>
					</select>
 				</td>
			</tr>
   		</tbody>
    </table>
 
	</fieldset>
	<?php
}


add_action('save_post', 'custom_add_save');

function custom_add_save($postID){

  
	// called after a post or page is saved
	if($parent_id = wp_is_post_revision($postID))
	{
	  $postID = $parent_id;
	}

	if ($_POST['save'] || $_POST['publish']) {
	
	$options = array();
	
	foreach (option::$options as $option => $val) {
	    if (strpos($option, 'listing') !== false && trim($val) != '') {
	        $options[] = $val;
	    }
	}
	
	foreach ($options as $option) {
	    $id = strtolower(str_replace(" ", "_", preg_replace("/[^a-zA-Z0-9\s]/", "", $option)));

  	    update_custom_meta($postID, $_POST['wpzoom_estate_' . $id], 'wpzoom_estate_' . $id);
    }   	

   	update_custom_meta($postID, $_POST['wpzoom_post_template'], 'wpzoom_post_template');
	update_custom_meta($postID, $_POST['wpzoom_estate_wpzaddress'], 'wpzoom_estate_wpzaddress');
	update_custom_meta($postID, $_POST['wpzoom_estate_wpzprice'], 'wpzoom_estate_wpzprice');
   	update_custom_meta($postID, $_POST['wpzoom_estate_wpzbedroom'], 'wpzoom_estate_wpzbedroom');
   	update_custom_meta($postID, $_POST['wpzoom_estate_wpzbathroom'], 'wpzoom_estate_wpzbathroom');
	}
}


function update_custom_meta($postID, $newvalue, $field_name) {
// To create new meta
if(!get_post_meta($postID, $field_name)){
add_post_meta($postID, $field_name, $newvalue);
}else{
// or to update existing meta
update_post_meta($postID, $field_name, $newvalue);
}
}

 

/*	Register custom post types
==================================== */

function wpzoom_create_post_type_estates() 
{
	$labels = array(
		'name' => __( 'Properties'),
		'singular_name' => __( 'Property' ),
		'rewrite' => array('slug' => __( 'property' )),
		'add_new' => _x('Add New', 'slide'),
		'add_new_item' => __('Add New Property'),
		'edit_item' => __('Edit Property'),
		'new_item' => __('New Property'),
		'view_item' => __('View Property'),
		'search_items' => __('Search Properties'),
		'not_found' =>  __('No properties found'),
		'not_found_in_trash' => __('No properties found in Trash'), 
		'parent_item_colon' => ''
	  );
	  
	  $args = array(
		'labels' => $labels,
		'public' => true,
		'publicly_queryable' => true,
		'show_ui' => true, 
		'query_var' => true,
		'rewrite' => true,
		'capability_type' => 'post',
		'hierarchical' => false,
		'rewrite' => array(	"slug" => "property"	), 
		'menu_position' => null,
		'show_in_nav_menus'	=> true,
		'has_archive' => true,
		'has_archive' => true,
		'menu_icon' => get_template_directory_uri() .'/images/house.png', // 16px16
 		'supports' => array('title', 'author', 'excerpt', 'editor','thumbnail'),
		'taxonomies' => array(	'location', 'types', 'status', 'propertyfeatures')
	  ); 
	  
	  register_post_type(__( 'estate' ),$args);
}


// Styling for the custom post type icon
add_action( 'admin_head', 'wp_estate_icon' );
 
function wp_estate_icon() {
    ?>
    <style type="text/css" media="screen">
 		#icon-edit.icon32-posts-estate {background: url(<?php bloginfo('template_directory'); ?>/images/house-32.png) no-repeat;}
 		#adminmenu .wp-menu-image img {opacity:0.8; }
    </style>
<?php }

 


/*	Create custom taxonomies for the estate post type
======================================================= */
function wpzoom_build_taxonomies(){
	register_taxonomy( "location" ,
		array ( "estate" ), 
		array ( "hierarchical" => true, 
				'labels' => array(	'name'				=> __('Locations'),
									'singular_name' 	=> __('Location'),
									'search_items' 		=> __('Search Real Estate'),
									'popular_items' 	=> __('Popular Locations'),
									'all_items' 		=> __('All'),
									'parent_item' 		=> __('Parent Location'),
									'parent_item_colon' => __('Parent Location:'),
									'edit_item' 		=> __('Edit Location'),
									'update_item'		=> __('Update Location'),
									'add_new_item' 		=> __('Add New Location'),
									'new_item_name' 	=> __('New Location Name')	), 
				'public' => true,
				'show_ui' => true,
				"rewrite" => array('slug' => 'location', 'hierarchical' => true))); 
	
	register_taxonomy( "types" ,
		array ( "estate" ), 
		array ( "hierarchical" => true, 
				'labels' => array(	'name'				=> __('Property Types'),
									'singular_name' 	=> __('Property Type'),
									'search_items' 		=> __('Search Property Types'),
									'popular_items' 	=> __('Popular Property Types'),
									'all_items' 		=> __('All'),
									'parent_item' 		=> __('Parent Property Type'),
									'parent_item_colon' => __('Parent Property Type:'),
									'edit_item' 		=> __('Edit Property Type'),
									'update_item'		=> __('Update Property Type'),
									'add_new_item' 		=> __('Add New Property Type'),
									'new_item_name' 	=> __('New Property Type Name')), 

				'public' => true,
				'show_ui' => true,
				"rewrite" => array('slug' => 'types', 'hierarchical' => true))); 
  	
	register_taxonomy( "status" ,
		array ( "estate" ), 
		array ( "hierarchical" => true, 
				'labels' => array(	'name'				=> __('Property Status'),
									'singular_name' 	=> __('Property Status'),
									'search_items' 		=> __('Search Property Statuses'),
									'popular_items' 	=> __('Popular Property Statuses'),
									'all_items' 		=> __('All'),
									'parent_item' 		=> __('Parent Property Status'),
									'parent_item_colon' => __('Parent Property Status:'),
									'edit_item' 		=> __('Edit Property Status'),
									'update_item'		=> __('Update Property Status'),
									'add_new_item' 		=> __('Add New Status'),
									'new_item_name' 	=> __('New Property Status Name') ), 

				'public' => true,
				'show_ui' => true,
				"rewrite" => array('slug' => 'status', 'hierarchical' => true))); 
	}



/* Move taxonomies metaboxes to main column
============================================= */

add_action( 'admin_menu', 'remove_default_metaboxes' );
function remove_default_metaboxes() {
    remove_meta_box( 'locationdiv', 'estate', 'side' );
    remove_meta_box( 'statusdiv', 'estate', 'side' );
    remove_meta_box( 'typesdiv', 'estate', 'side' );
}


/* Define default terms for custom taxonomies in WordPress 3.2
   @author    Tanju POLAT     http://www.comturkey.com/
========================================================= */

function wpzoom_set_default_taxonomy_terms() {

	if(isset($_GET['page']) && $_GET['page'] == 'wpzoom_options') {
	
		$taxCheck = option::get('taxonomies_loaded', 0);
		
		global $wpdb;

		if ($taxCheck != 1) {
		
		// Manually insert into database default terms for the 'status' taxonomy 
		$taxies = array('for-sale' => 'For Sale', 'for-rent' => 'For Rent', 'commercial' => 'Commercial');
		
		foreach ($taxies as $key => $value)
		{
			$wpdb->insert($wpdb->terms,	array('name' => $value, 'slug' => $key),array('%s','%s'));
			$taxID = $wpdb->insert_id;
			$wpdb->insert($wpdb->term_taxonomy,	array('term_id' => $taxID, 'taxonomy' => 'status'),array('%d','%s'));
		}


		// Manually insert into database default terms for the 'types' taxonomy 
		$taxies = array('residential' => 'Residential', 'single-family-house' => 'Single Family House', 'apartments' => 'Apartments');
		
		foreach ($taxies as $key => $value)
		{
			$wpdb->insert($wpdb->terms,	array('name' => $value, 'slug' => $key),array('%s','%s'));
			$taxID = $wpdb->insert_id;
			$wpdb->insert($wpdb->term_taxonomy,	array('term_id' => $taxID, 'taxonomy' => 'types'),array('%d','%s'));
		}

		option::set('taxonomies_loaded', 1);
		
		}
	}

}
add_action( 'init', 'wpzoom_set_default_taxonomy_terms', 10,0);

// Define the function that will create the join string
function mam_custom_field_range($keyname='',$min=false,$max=false) {
  global $mam_global_join,$wpdb;
  if ($keyname && ($min !== false || $max !== false)) {
    $mam_global_join =
      " JOIN $wpdb->postmeta acfr_$keyname ON
      ( $wpdb->posts.ID = acfr_$keyname.post_id
        AND acfr_$keyname.meta_key = '$keyname'";
    if ($min !== false) $mam_global_join .= " AND acfr_$keyname.meta_value >= $min";
    if ($max !== false) $mam_global_join .= " AND acfr_$keyname.meta_value <= $max";
    $mam_global_join .= ')';
  }
}
// Define the join filter function
function mam_posts_join ($join) {
   global $mam_global_join;
   if ($mam_global_join) $join .= $mam_global_join;
   return $join;
}
// Add the filter to the hooks
add_filter('posts_join','mam_posts_join');


 
function make_terms_dropdown($tax, $taxs, $taxonomies) {
    $args = array('parent' => 0,
            'hide_empty' => 1,
            'hierarchical' => 1
        );
    $myterms = get_terms( $taxonomies, $args );
    $output = "<select name='$tax' id='$tax' class='postform'>";
    $output .= "<option value='0'>All $taxs</option>";
    foreach ($myterms as $term){
        $term_taxonomy = $term->taxonomy;
        $term_slug = $term->slug;
        $term_name = $term->name;
        $term_id = $term->term_id;
        $output .= "<option value='".$term_slug."'>".$term_name."</option>";
        $termchildren = get_term_children( $term_id, $term_taxonomy );
        if ($termchildren) {
            $padd = "&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;";
            foreach ($termchildren as $child) {
                $cterm = get_term_by( 'id', $child, $term_taxonomy );
                $cterm_slug = $cterm->slug;
                $cterm_name = $cterm->name;
                $output .= "<option value='".$cterm_slug."'>".$padd.$cterm_name."</option>";
            }
        }
    }
    $output .="</select>";
return $output;
}



/* Register custom columns in admin for Property post type
========================================================= */
function wpzoom_slide_edit_columns($columns){  

        $columns = array(  
            "cb" => "<input type=\"checkbox\" />",  
            "title" => __( 'Slide Title' )
        );  
  
        return $columns;  
}  
 
 
add_action( 'init', 'wpzoom_create_post_type_estates' );
add_action( 'init', 'wpzoom_build_taxonomies', 0 );
add_filter("manage_edit-slide_columns", "wpzoom_slide_edit_columns");  
add_filter("manage_edit-estate_columns", "wpzoom_estate_edit_columns");  
add_action("manage_posts_custom_column",  "wpzoom_estate_custom_columns");  

//custom post type edit headers
	function wpzoom_estate_edit_columns($columns)
	{
	
		$currency = option::get('currency');
		
		$columns = array(
			"cb" => "<input type=\"checkbox\" />",
 			"title" => "Property Title",
 			"wpzoom_estate_thumbnail" => "Thumbnail",
 			"wpzoom_estate_locations" => "Location",
			"wpzoom_estate_types" => "Type",
			"wpzoom_estate_status" => "Status",
			"wpzoom_estate_wpzprice" => "Price in $currency",
		);
		
		return $columns;
	}
	
	//custom post type edit output
	function wpzoom_estate_custom_columns($column)
	{
		global $post;
		switch ($column)
		{
 			case "wpzoom_estate_thumbnail":
				the_post_thumbnail( array(100,100) );
				break;
 			case "wpzoom_estate_locations":
				$locations = get_the_terms($post->ID, "location");
				$locations_html = array();
				if ($locations) {
				foreach ($locations as $location)
					array_push($locations_html, '<a href="' . get_term_link($location->slug, "location") . '">' . $location->name . '</a>');
				
				echo implode($locations_html, ", ");
				} else {
					_e('None', 'wpzoom');;
				}
				break;
			case "wpzoom_estate_types":
				$types = get_the_terms($post->ID, "types");
				$types_html = array();
				if ($types) {
				foreach ($types as $type)
					array_push($types_html, '<a href="' . get_term_link($type->slug, "types") . '">' . $type->name . '</a>');
				
				echo implode($types_html, ", ");
				} else {
					_e('None', 'wpzoom');;
				}
				break;
				
			case "wpzoom_estate_status":
				$status = get_the_terms($post->ID, "status");
				$status_html = array();
				if ($status) {
				foreach ($status as $stat)
					array_push($status_html, '<a href="' . get_term_link($stat->slug, "status") . '">' . $stat->name . '</a>');
				
				echo implode($status_html, ", ");
				} else {
					_e('None', 'wpzoom');;
				}
				break;
				
			case "wpzoom_estate_wpzprice":
				$custom = get_post_custom();
				$price = $custom["wpzoom_estate_wpzprice"][0];
 				$output = '';
 				if ($price != '') { echo ''.$price.''; }
 				
				break;
		}
	} 
 

/* Metabox to add posts in slider
==================================== */
$wpzoom_featured_fields = array(
	array(
		"name"			=> "wpzoom_is_featured",
		"label"			=> "Feature in Homepage Slider",
		"type"			=> "checkbox"
	), 
	
	/*
	array(
		"name"			=> "wpzoom_is_hide",
		"label"			=> "Hide in Recent Listings",
		"type"			=> "checkbox"
	), 
	*/
	
	array(
		"name"		=> "wpzoom_featured_title",
		"label" 	=> "Featured Title (leave empty for post title)",
		"type"		=> "text"
	),   
	
	array(
		"name"		=> "wpzoom_featured_description",
		"label" 	=> "Featured Description (leave empty for post excerpt)",
		"type"		=> "textarea"
	),   
);

function wpzoom_featured_meta( $post_data, $meta_info ) {
	global $post, $wpzoom_featured_fields;
	echo '<div class="wpzoom_panel"><input type="hidden" name="wpzoom_featured_metaes_nonce" value="'.wp_create_nonce( plugin_basename(__FILE__) ).'" />';
	foreach( $wpzoom_featured_fields as $o ){
		$val = get_post_meta( $post->ID, $o['name'], true );
		echo '<p>';

		switch ( $o['type'] ){
			case "checkbox":
				$isChecked = ( $val == 1 ? 'checked="checked"' : '' ); // we store checked checkboxes as 1
				echo '<input type="checkbox" name="' . $o['name'] . '" id="' . $o['name'] . '" ' . $isChecked . ' /> <label for="' . $o['name'] . '" >' . $o['label'] . '</label>';
			break; // checkbox
			
			case "textarea":
				echo '<textarea name="' . $o['name'] . '" id="' . $o['name'] . '" cols="10" rows="5" placeholder="' . $o['label'] . '">' . $val . '</textarea>';
			break; // textarea

			case "text":
				default:
				echo '<input type="text" name="' . $o['name'] . '" id="' . $o['name'] . '" value="' . $val . '" placeholder="' . $o['label'] . '" />';
			break; // text & default

			 
		}// switch

	}// foreach
	echo '</div>';
?>

<style type="text/css" media="screen">
	.wpzoom_panel input[type="text"],
	.wpzoom_panel textarea { width: 100%; }
	.wpzoom_panel .desc { text-align: right; }
	#newlocation_parent, #newtypes_parent, #newstatus_parent { display: none; }
	#post-body #newlocation, #post-body #newtypes, #post-body #newstatus { width: 200px; }
	#post-body .category-add input, .category-add select { width: auto; }
	.estate_details .postbox { border: none; background: none; box-shadow: none; }
	 #wpzoom_estate_default .inside, #wpzoom_estate_meta .inside { margin: 0; padding: 0; }
	.inside table.estate_details.widefat { border: 0; }
	.inside table.estate_details.widefat th { background: #ececec; padding-left: 15px; vertical-align: top; width: 150px; }
	.inside table.estate_details.widefat td { border-bottom: 1px solid #EFEFEF; vertical-align: middle; padding: 10px; }
	.inside table.estate_details.widefat textarea { width: 100%; }
	.inside table.estate_details.widefat .description { color: #C1C1C1; float: right; font-style: normal; padding: 5px 0; }
	.inside table.estate_details.widefat option { padding-right: 15px; }
	.inside table.estate_details.widefat input[type="text"] { width: 350px; }
	.estate_details select { width: 150px; }
	#location-add,#types-add,#status-add { width: 100%; }
	.estate_details div.tabs-panel { width: 60%; }
	.categorydiv div.tabs-panel, .customlinkdiv div.tabs-panel,.posttypediv div.tabs-panel, .taxonomydiv div.tabs-panel, #linkcategorydiv div.tabs-panel { height: 116px; }
 </style>

<?php 
}

function wpzoom_create_featured_meta() {
	if ( function_exists( 'add_meta_box' ) ) {
		add_meta_box( 'wpzoom_featured_meta', 'Feature this Listing?', 'wpzoom_featured_meta', 'estate', 'side', 'high' );
	}
}

function wpzoom_save_featured_meta( $post_id ) {

	global $post, $post_id, $wpzoom_featured_fields;
	if ( in_array( $_REQUEST['post_type'], array('page') ) ) {
		if ( !current_user_can( 'edit_page', $post_id ) ) {return $post_id;}
	} else {
		if ( !current_user_can( 'edit_post', $post_id ) ) {return $post_id;}
	}

	foreach($wpzoom_featured_fields as $o){
		if ( !wp_verify_nonce( $_REQUEST['wpzoom_featured_metaes_nonce'], plugin_basename(__FILE__) )) {
			return $post_id;
		}
		switch ($o['type']){
			case "checkbox":
				update_post_meta( $post_id, $o['name'], isset( $_REQUEST[$o['name']] ) );
			break;
			default:
				update_post_meta($post_id, $o['name'], $_REQUEST[$o['name']]);
			break;
		}
	}
}
add_action( 'admin_menu', 'wpzoom_create_featured_meta' );  
add_action( 'save_post', 'wpzoom_save_featured_meta' );

?>